@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use File::Copy;
 use File::Path;
@@ -75,7 +75,7 @@ our @EXPORTABLE = qw(
 cp rmf mkd cd make 
 cdback download untar 
 pie slurp blurt mv tap 
-plough qquote quote perm_cp
+plough qquote quote perm_cp owner_cp
 perm_get perm_set
 sysrun untar_in pick ask
 hammer say
@@ -956,6 +956,16 @@ wrapping all args so that shell variables are interpolated properly:
 
     "ls" "/tmp/$VAR" 2>/tmp/sometempfile |
 
+Another option is "utf8" which runs the command in a terminal set to 
+UTF8.
+
+Error handling: By default, tap() won't raise an error if the command's
+return code is nonzero, indicating an error reported by the shell. If 
+bailing out on errors is requested to avoid return code checking by
+the script, use the raise_error option:
+
+    tap({raise_error => 1}, "ls", "doesn't exist");
+
 =cut
 
 ###############################################
@@ -1010,6 +1020,10 @@ sub tap {
 
     my $exit_code = $?;
 
+    if($opts->{raise_error}) {
+        LOGCROAK("tap $cmd | failed ($!)");
+    }
+
     my $stderr = slurp($tmpfile, $options);
 
     DEBUG "tap $cmd results: rc=$exit_code stderr=[$stderr] stdout=[$stdout]";
@@ -1197,6 +1211,51 @@ sub perm_cp {
 
 =pod
 
+=item C<owner_cp($src, $dst, ...)>
+
+Read the C<$src> file/directory's owner uid and group gid and apply
+it to $dst.
+
+For example: copy uid/gid of the containing directory to a file
+therein:
+
+    use File::Basename;
+
+    owner_cp( dirname($file), $file );
+
+Usually requires root privileges, just like chown does.
+
+=cut
+
+######################################
+sub owner_cp {
+######################################
+    my($src, @dst) = @_;
+
+    local $Log::Log4perl::caller_depth =
+          $Log::Log4perl::caller_depth + 1;
+
+    _confirm "owner_cp @_" or return 1;
+
+    LOGCROAK("usage: owner_cp src dst ...") if @_ < 2;
+
+    my($uid, $gid) = (stat($src))[4,5];
+
+    if(!defined $uid or !defined $gid ) {
+        LOGCROAK("stat of $src failed: $!");
+        return undef;
+    }
+
+    if(!chown $uid, $gid, @dst ) {
+        LOGCROAK("chown of ", join(" ", @dst), " failed: $!");
+        return undef;
+    }
+
+    return 1;
+}
+
+=pod
+
 =item C<$perms = perm_get($filename)>
 
 Read the C<$filename>'s user permissions and owner/group. 
@@ -1514,8 +1573,7 @@ sub pipe_copy {
 Format the data string in C<$data> so that it's only (roughly) $maxlen
 characters long and only contains printable characters.
 
-If C<$data> contains unprintable character's they are replaced by 
-"." (the dot). If C<$data> is longer than C<$maxlen>, it will be
+If C<$data> is longer than C<$maxlen>, it will be
 formatted like
 
     (22)[abcdef[snip=11]stuvw]
@@ -1523,6 +1581,12 @@ formatted like
 indicating the length of the original string, the beginning, the
 end, and the number of 'snipped' characters.
 
+If C<$data> is shorter than $maxlen, it will be returned unmodified 
+(except for unprintable characters replaced, see below).
+
+If C<$data> contains unprintable character's they are replaced by 
+"." (the dot).
+
 =cut
 
 ###########################################
@@ -1531,7 +1595,7 @@ sub snip {
     my($data, $maxlen) = @_;
 
     if(length $data <= $maxlen) {
-        return lenformat($data);
+        return printable($data);
     }
 
     $maxlen = 12 if $maxlen < 12;
